@@ -71,7 +71,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	int sty=15;
 	extent_visible=false;
 
-	setFocusPolicy(TQ_NoFocus);
+	setFocusPolicy(TQWidget::NoFocus);
 	TDEConfig *cfg = TDEApplication::kApplication()->config();
 	if (cfg)
 	{
@@ -86,7 +86,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	esc->setText ( "Esc" );
 	esc->res();
 	other_keys.append(esc);
-	connect ( esc,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( esc,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	for ( int a=0;a<4;a++ )
 	{
@@ -96,7 +96,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		f->move ( stx+esc->width() + ( 35*a ) +30,sty );
 		f->res();
 		other_keys.append(f);
-		connect ( f,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( f,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	}
 	for ( int a=0;a<4;a++ )
 	{
@@ -106,7 +106,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		f->move ( stx+esc->width() + ( 35*a ) +44+ ( 4*35 ),sty );
 		f->res();
 		other_keys.append(f);
-		connect ( f,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( f,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	}
 	for ( int a=0;a<4;a++ )
 	{
@@ -117,7 +117,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		f->move ( stx+esc->width() + ( 35*a ) +58+ ( 8*35 ),sty );
 		f->res();
 		other_keys.append(f);
-		connect ( f,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( f,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	}
 
 	//ROW 1
@@ -126,7 +126,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		VButton *v = new VButton ( this,"" );
 		v->setKeyCode ( kc1[a] );
 		v->move ( stx+ ( 35*a ),sty+35 );
-		connect ( v,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( v,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 		btns.append ( v );
 		v->res();
 	}
@@ -138,7 +138,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	bksp->setText ( "Bksp" );
 	bksp->res();
 	other_keys.append(bksp);
-	connect ( bksp,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( bksp,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	//ROW 2
 	VButton *tab = new VButton ( this,"" );
@@ -148,7 +148,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	tab->setText ( "Tab" );
 	tab->res();
 	other_keys.append(tab);
-	connect ( tab,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( tab,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	for ( int a=0;a<R2LEN;a++ )
 	{
@@ -158,7 +158,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		//v->setShiftText ( k2s.mid ( a,1 ) );
 		v->move ( stx+tab->width() +5+ ( 35*a ),sty+35+35 );
 		v->res();
-		connect ( v,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( v,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 		btns.append ( v );
 	}
 
@@ -168,7 +168,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	//lbr->setText ( "[" );
 	//lbr->setShiftText ( "{" );
 	lbr->res();
-	connect ( lbr,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( lbr,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( lbr );
 
 	VButton *rbr = new VButton ( this,"" );
@@ -177,7 +177,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	//rbr->setText ( "]" );
 	//rbr->setShiftText ( "}" );
 	rbr->res();
-	connect ( rbr,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( rbr,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( rbr );
 
 	VButton *bksl = new VButton ( this,"" );
@@ -187,7 +187,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	//bksl->setText ( "\\" );
 	//bksl->setShiftText ( "|" );
 	bksl->res();
-	connect ( bksl,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( bksl,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( bksl );
 
 	//ROW 3
@@ -197,7 +197,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	caps->resize ( 63,30 );
 	caps->setText ( "Caps" );
 	caps->setToggleButton ( true );
-	connect ( caps,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( toggleShiftCapsAltGr ( unsigned int ) ) );
+	connect ( caps,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( toggleShiftCapsAltGr ( unsigned int ) ) );
 	other_keys.append(caps);
 	caps->res();
 
@@ -210,14 +210,14 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		v->move ( stx+caps->width() +5+ ( 35*a ),sty+ ( 3*35 ) );
 		btns.append ( v );
 		v->res();
-		connect ( v,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( v,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	}
 	VButton *smcl = new VButton ( this,"" );
 	smcl->setKeyCode ( 47 );
 	smcl->move ( stx+ ( R3LEN *35 ) +caps->width() +5,sty+ ( 3*35 ) );
 	//smcl->setText ( ";" );
 	//smcl->setShiftText ( ":" );
-	connect ( smcl,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( smcl,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( smcl );
 	smcl->res();
 
@@ -226,7 +226,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	sngq->move ( stx+ ( ( R3LEN +1 ) *35 ) +caps->width() +5,sty+ ( 3*35 ) );
 	//sngq->setText ( "'" );
 	//sngq->setShiftText ( "\"" );
-	connect ( sngq,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( sngq,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( sngq );
 	sngq->res();
 
@@ -235,7 +235,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	enter->move ( stx+ ( ( R3LEN +2 ) *35 ) +caps->width() +5,sty+ ( 3*35 ) );
 	enter->resize ( 50,30 );
 	enter->setText ( "Enter" );
-	connect ( enter,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( enter,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	other_keys.append(enter);
 	enter->res();
 
@@ -246,7 +246,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	lshift->resize ( 45,30 );
 	lshift->setText ( "Shift" );
 	lshift->setToggleButton ( true );
-	connect ( lshift,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( toggleShiftCapsAltGr( unsigned int ) ) );
+	connect ( lshift,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( toggleShiftCapsAltGr( unsigned int ) ) );
 	mod_keys.append ( lshift );
 	lshift->res();
 
@@ -259,7 +259,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		v->move ( stx+lshift->width() +5+ ( 35*a ),sty+ ( 4*35 ) );
 		btns.append ( v );
 		v->res();
-		connect ( v,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+		connect ( v,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	}
 
 	VButton *sm = new VButton ( this,"" );
@@ -267,7 +267,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	sm->move ( stx+ ( R4LEN *35 ) +lshift->width() +5,sty+ ( 4*35 ) );
 	//sm->setText ( "," );
 	//sm->setShiftText ( "<" );
-	connect ( sm,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( sm,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( sm );
 	sm->res();
 
@@ -276,7 +276,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	gr->move ( stx+ ( ( R4LEN +1 ) *35 ) +lshift->width() +5,sty+ ( 4*35 ) );
 	//gr->setText ( "." );
 	//gr->setShiftText ( ">" );
-	connect ( gr,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( gr,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( gr );
 	gr->res();
 
@@ -285,7 +285,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	sl->move ( stx+ ( ( R4LEN +2 ) *35 ) +lshift->width() +5,sty+ ( 4*35 ) );
 	//sl->setText ( "/" );
 	//sl->setShiftText ( "?" );
-	connect ( sl,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( sl,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	btns.append ( sl );
 	sl->res();
 
@@ -295,7 +295,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	rshift->resize ( 68,30 );
 	rshift->setText ( "Shift" );
 	rshift->setToggleButton ( true );
-	connect ( rshift,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( toggleShiftCapsAltGr( unsigned int ) ) );
+	connect ( rshift,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( toggleShiftCapsAltGr( unsigned int ) ) );
 	mod_keys.append ( rshift );
 	rshift->res();
 
@@ -332,7 +332,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	space->resize ( 133,30 );
 	space->move ( lalt->x() +lalt->width() +5, sty+ ( 5*35 ) );
 
-	connect ( space, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( space, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	space->res();
 	other_keys.append(space);
 
@@ -342,7 +342,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	ralt->setText ( "AltGr" );
 	ralt->setKeyCode ( 108 );
 	ralt->setToggleButton ( true );
-	connect ( ralt,TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( toggleShiftCapsAltGr ( unsigned int ) ) );
+	connect ( ralt,TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( toggleShiftCapsAltGr ( unsigned int ) ) );
 	mod_keys.append ( ralt );
 	ralt->res();
 
@@ -361,7 +361,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	mnu->setText ( "Menu" );
 	mnu->setKeyCode ( 135 );
 	mnu->setToggleButton ( false );
-	connect ( mnu, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( mnu, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	other_keys.append(mnu);
 	mnu->res();
 
@@ -381,7 +381,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	TQToolTip::add( quit, i18n( "Hide keyboard" ) );
 	quit->res();
 	other_keys.append(quit);
-	connect ( quit,TQT_SIGNAL ( clicked() ),this, TQT_SLOT ( quitClicked() ) );
+	connect ( quit,TQ_SIGNAL ( clicked() ),this, TQ_SLOT ( quitClicked() ) );
 
 	extent = new VButton(this,"extent");
 	extent->resize ( 20,65 );
@@ -398,10 +398,10 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	}
 	extent->res();
 	other_keys.append(extent);
-	connect (extent, TQT_SIGNAL( clicked() ) , this, TQT_SLOT ( toggleNumericPad() ) );
+	connect (extent, TQ_SIGNAL( clicked() ) , this, TQ_SLOT ( toggleNumericPad() ) );
  
 	TQTimer *t = new TQTimer ( this );
-	connect ( t, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( queryModState() ) );
+	connect ( t, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( queryModState() ) );
 	t->start ( 500, FALSE );
 
 	int padx= 554;
@@ -420,7 +420,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 			v->setText(txt[val]);
 			v->setShiftText(nump[val]);
 			numl_keys.append(v);
-			connect ( v, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+			connect ( v, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 			val++;
 		}
 	}
@@ -433,7 +433,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	ins->setShiftText("0");
 	numl_keys.append(ins);	
 	
-	connect ( ins, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( ins, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	del = new NumpadVButton(this,"del");
 	del->resize(30,30);
@@ -443,7 +443,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	del->setShiftText(".");
 	del->setKeyCode(91);
 	numl_keys.append(del);
-	connect ( del, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( del, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	
 
 	numl = new VButton(this,"numlock");
@@ -453,7 +453,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	numl->setText("Num\nLock");
 	numl->setToggleButton ( true );
 	other_keys.append(numl);
-	connect ( numl, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( toggleNumlock() ) );
+	connect ( numl, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( toggleNumlock() ) );
 
 
 	div = new VButton(this,"div");
@@ -462,7 +462,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	div->setText("/");
 	div->setKeyCode(106);
 	other_keys.append(div);
-	connect ( div, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( div, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	mul = new VButton(this,"mul");
 	mul->move(padx+(2*35),sty+(1*35));
@@ -470,7 +470,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	mul->setText("*");
 	mul->setKeyCode(63);
 	other_keys.append(mul);	
-	connect ( mul, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( mul, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 	
 	ent = new VButton(this,"enter1");
 	ent->resize(30,65);
@@ -479,7 +479,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	ent->setText("En\nter");
 	ent->setKeyCode(104);
 	other_keys.append(ent);
-	connect ( ent, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( ent, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	plu = new VButton(this,"plus");
 	plu->resize(30,65);
@@ -488,7 +488,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	plu->setText("+");
 	plu->setKeyCode(86);
 	other_keys.append(plu);
-	connect ( plu, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( plu, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	min = new VButton(this,"minus");
 	min->resize(30,30);
@@ -497,7 +497,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 	min->setKeyCode(82);
 	other_keys.append(min);
 	min->res();
-	connect ( min, TQT_SIGNAL ( keyClick ( unsigned int ) ), this, TQT_SLOT ( keyPress ( unsigned int ) ) );
+	connect ( min, TQ_SIGNAL ( keyClick ( unsigned int ) ), this, TQ_SLOT ( keyPress ( unsigned int ) ) );
 
 	mappingNotify(NULL);
 
@@ -512,25 +512,25 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		m->setCheckable ( true );
 
 		KHelpMenu *h = new KHelpMenu ( tray, about );
-		m->insertItem ( i18n("Font ..."), this, TQT_SLOT ( chooseFont() ) );
+		m->insertItem ( i18n("Font ..."), this, TQ_SLOT ( chooseFont() ) );
 
-		mnu_autores = m->insertItem( i18n("Auto resize font"),this, TQT_SLOT ( toggleFontAutoRes() ) );
+		mnu_autores = m->insertItem( i18n("Auto resize font"),this, TQ_SLOT ( toggleFontAutoRes() ) );
 		bool fnt_autores = cfg->readBoolEntry("autoresfont",true);
 		m->setItemChecked(mnu_autores, fnt_autores);
 
-		m->insertItem ( i18n ("Background color"), this, TQT_SLOT ( chooseBackgroundColor() ) );
-		m->insertItem ( i18n ("Keys color"), this, TQT_SLOT ( chooseKeysColor() ) );
+		m->insertItem ( i18n ("Background color"), this, TQ_SLOT ( chooseBackgroundColor() ) );
+		m->insertItem ( i18n ("Keys color"), this, TQ_SLOT ( chooseKeysColor() ) );
 
 		m->insertSeparator();
-		mnu_dock = m->insertItem ( i18n("Dock widget"), this, TQT_SLOT ( showDock() ) );
+		mnu_dock = m->insertItem ( i18n("Dock widget"), this, TQ_SLOT ( showDock() ) );
 		bool show_dock = cfg->readBoolEntry("showdock",false);
 		m->setItemChecked(mnu_dock, show_dock);
 
-		mnu_lock = m->insertItem(i18n("Lock on screen"), this, TQT_SLOT(toggleLock()));
+		mnu_lock = m->insertItem(i18n("Lock on screen"), this, TQ_SLOT(toggleLock()));
 		locked = cfg->readBoolEntry("locked", false);
 		m->setItemChecked(mnu_lock, locked);
 
-		//m->insertItem("Configure", this, TQT_SLOT(config()));
+		//m->insertItem("Configure", this, TQ_SLOT(config()));
 		m->insertSeparator();
 		m->insertItem ( i18n("Help"), h->menu() );
 		
@@ -561,7 +561,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
 		popup_menu->setPixmap(TQIconSet(SmallIcon("configure", TDEIcon::SizeMedium)).pixmap());
 		TQToolTip::add( popup_menu, i18n( "Configure" ) );
 		other_keys.append(popup_menu);
-		connect ( popup_menu,TQT_SIGNAL ( clicked() ),this, TQT_SLOT ( showConfigMenu() ) );
+		connect ( popup_menu,TQ_SIGNAL ( clicked() ),this, TQ_SLOT ( showConfigMenu() ) );
 	}
 	else
 	{
@@ -953,7 +953,7 @@ KbdDock::KbdDock ( MainWidget *m )
 		: DragWidget ( 0, "Dock", WStyle_Customize | TQt::WX11BypassWM |WStyle_NormalBorder ), mainWidget ( m )
 {
 
-	setFocusPolicy ( TQ_NoFocus );
+	setFocusPolicy ( TQWidget::NoFocus );
 	icn=UserIcon ( "dock" );
 	resize ( 96,47 );
 
@@ -991,7 +991,7 @@ KbdTray::KbdTray(TQWidget *parent, const char *name) : KSystemTray(parent,name)
 
 void KbdTray::mousePressEvent(TQMouseEvent *e)
 {
-	if (e->button()==Qt::LeftButton) {
+	if (e->button()==TQt::LeftButton) {
 		TQWidget *p = parentWidget();
 		if (p){
 			if (p->isShown()){
